macroScript TheRenderer
category:"KFScripts"  
toolTip:"The Renderer" 
buttonText:"The Renderer"
-----------------------------
----v.2.02 of The Renderer---
---Written by Kiel Figgins---
-----www.3dfiggins.com-------
-----------------------------
--Abridged version of multiple tools and processes to produce
--Renders of Animations and Still frames, in multiple formats. 
--creates and allows you explict control over a 
--3 point light setup, a faux Global illumational setup, material control, 
--scene aspects, view aspects, rendering settings and output formates
-----------------------------
--Version History
--2.02 (07-13-2006) - Convert Material now works with layered Shader
--2.01 (06-14-2006) - Open previous file on close added, various small tweeks
--2.00 (05-25-2006) - Heavy rework on interface, added functionality to material control, safe frame and bg curve deleting
--1.31 (04-21-2006) - On startup global tint set to white to show shadows
--1.30 (04-19-2006) - Delete All for 3 point lighting more solid, adjusted initial shadow density
--1.29 (03-31-2006) - Modified open location to prevent the window from docking
--1.28 (03-21-2006) - Modified material change on avatar to full bright, corrected window version
--1.27 (03-17-2006) - Added button to convert avatar material on 'Convert Material' and in the Tweeks section
--1.26 (03-17-2006) - Adjusted start up location
--1.25 (02-13-2006) - Clear selection after creating camera
--1.24 (02-11-2006) - Orginal Version
-----------------------------

(
global		Rheight = 105
global		Rwidth = 140
global		nframe = 3
global		keyIntensity=bezier_float()
global		mainIntensity=bezier_float()
global		hotpick = 5
global		renderType = 0
global		namer
global		key3pIntensity=bezier_float()
global		fill3pIntensity=bezier_float()
global		rim3pIntensity=bezier_float()
global		viewSetupStart
global		viewSetup
global 		yourPath
global 		yourName
-----------------------------------------------------------------------------------------------------------
-- Rollouts
-----------------------------------------------------------------------------------------------------------
try(cui.FloatDialogBar RendererDialog)catch()
try(cui.unRegisterDialogBar RendererDialog)catch()
try(destroydialog RendererDialog)catch()

-----------------------------------------------------------------------------------------------------------
-- RolloutA Rollout
-----------------------------------------------------------------------------------------------------------
rollout rolloutA_rol "Camera" 
	(
	on rolloutA_rol rolledUp state do
		(
		if rolloutA_rol.open == true then
			RendererDialog.rolloutA.height = 109
		else
			RendererDialog.rolloutA.height = 25
		RendererDialog.refreshmyrollouts()
		)

	on rolloutA_rol open do
		(
		if rolloutA_rol.open == true then
			RendererDialog.rolloutA.height = 109
		else
			RendererDialog.rolloutA.height = 25
		RendererDialog.refreshmyrollouts()
		)
	button btnimportCam "Import " pos:[3,3] width:42 height:17  toolTip: "Imports camera, if previously exported, into scene"
	button btncreateCam "Create" pos:[53,3] width:42 height:17 toolTip: "Create Camera"
	button btnexpCam "Export" pos:[3,21] width:42 height:17 toolTip: "Exports Camera for future use. Recalled by 'Import' button"
	button btndelCam "Delete" pos:[53,21] width:42 height:17 toolTip: "Deletes created camera"
	label lbllook "Look Through:" pos:[12,41] width:100 height:15
	button btnlookCam "Camera" pos:[3,56] width:42 height:17
	button btnlookPersp "Persp" pos:[53,56] width:42 height:17

on btncreateCam pressed do
(	  
try(delete $RendererCam) catch()
	  local c
	  local wcol = (color 5 54 179)
	  local targdist = getscreenscalefactor [0,0,0]
	  -- get viewport tm
	  local viewfov = getVIewFOV()
	  local cXform =  Inverse(viewport.getTM())
	  
	  --disablesceneredraw() 
	  -- perspective views
	  if viewport.Gettype() == #view_persp_user
	  then
		(
		if (superclassof selection[1]) == camera --check if selection is a camera
			then --if selection is a camera, than call the match camera to view action
			(
			  actionMan.executeAction 0 "40249" --loc_notes: do not localize this
			)
			else --if selection is not a camera, then create it for the user
			(
			  -- creates a camera, and assigns the current Vport Transforms
			  c = Freecamera  targetDistance:targdist isSelected:on wirecolor:wcol name:"RendererCam"
			  c.fov = viewfov
			  c.orthoProjection = false 
			  c.Transform = cXform 
			  viewport.setcamera c
			  print "Camera Created at Viewport"
			)--end then
		)--end then
		else
		(

		)--end else

	  -- clears the local variables
	  c = undefined 
	  viewfov = undefined
	  cXform  = undefined
	
clearSelection()
  
	  --enablesceneredraw()
)


on btnimportCam pressed do
(
try(delete $RendererCam) catch()
try
	(
	mergeMAXFile "C:\\Renderer\\Camera\\RendererCam.max" #useSceneMtlDups quiet:true
		try(viewport.setCamera $RendererCam) catch() -- Camera
	) 
catch()
)

on btnexpCam pressed do
(
try(
makeDir "C:\\Renderer"
makeDir "C:\\Renderer\\Camera"
saveNodes $RendererCam "C:\\Renderer\\Camera\\RendererCam.max"
) 
catch()
)

on btndelCam pressed do
(
try(delete $RendererCam) catch() 
)

on btnlookCam pressed do
(
try(viewport.setCamera $RendererCam) catch() -- Camera
)

on btnlookPersp pressed do
(
try(viewport.setType #view_persp_user) catch() -- Perspective
)


)--End of Camera Section
	


-----------------------------------------------------------------------------------------------------------
-- RolloutB Rollout
-----------------------------------------------------------------------------------------------------------
rollout rolloutB_rol "Materials" 
	(
	on rolloutB_rol rolledUp state do
		(
		if rolloutB_rol.open == true then
			RendererDialog.rolloutB.height = 170
		else
			RendererDialog.rolloutB.height = 25
		RendererDialog.refreshmyrollouts()
		)

	on rolloutB_rol open do
		(
		if rolloutB_rol.open == true then
			RendererDialog.rolloutB.height = 170
		else
			RendererDialog.rolloutB.height = 25
		RendererDialog.refreshmyrollouts()
		)
	spinner spnselfill "Self Illum:  " pos:[3,5] width:94 height:16 range:[0,100,80] 
	spinner spnspecLevel "Spec Lvl:  " pos:[3,24] width:94 height:16 range:[0,1000,0] 
	spinner spnGloss "Glossiness:" pos:[3,44] width:94 height:16 range:[0,100,0] 
	spinner spnSoften "Soften:      " pos:[3,63] width:94 height:16 range:[0,1,0] 
	label lblSelf "Self" pos:[2,84] width:20 height:15
	button btnSelfP10 "+" pos: [24,84] width:11 height:12
	button btnSelfM10 "-" pos: [37,84] width:11 height:12
	label lblSpec "Spec" pos:[49,84] width:24 height:15
	button btnSpecP10 "+" pos: [75,84] width:11 height:12
	button btnSpecM10 "-" pos: [88,84] width:11 height:12
	label lblGloss "Glos" pos:[2,100] width:24 height:15
	button btnGlossP10 "+" pos: [24,100] width:11 height:12
	button btnGlossM10 "-" pos: [37,100] width:11 height:12
	label lblSoft "Soft" pos:[53,100] width:24 height:15
	button btnSoftP10 "+" pos: [75,100] width:11 height:12
	button btnSoftM10 "-" pos: [88,100] width:11 height:12
	button btnmatPreview "Preview" pos:[2,115] width:45 height:18
	button btnMatEdit "Mat Edt." pos:[54,115] width:44 height:18  toolTip: "Opens Material Editor"
	
on spnselfill changed val do
	(
	--Define count Number
	matCounter01 = 1

	--Find out if its Layered
	try (matCounter01 = meditMaterials[14].count) 
	catch(
		meditMaterials[14].selfIllumAmount = val
	)--End of Catch

	if matCounter01 >= 1 then (
		for i=1 to (matCounter01) do
			(
				meditMaterials[14].materialList[i].selfIllumAmount = val
			)
		) else ()
	)--End of spnselfill

on spnspecLevel changed val do 
	(
	--Define count Number
	matCounter01 = 1

	--Find out if its Layered
	try (matCounter01 = meditMaterials[14].count) 
	catch(
		meditMaterials[14].specularLevel = val
	)--End of Catch

	if matCounter01 >= 1 then (
		for i=1 to (matCounter01) do
			(
				meditMaterials[14].materialList[i].specularLevel = val
			)
		) else ()
	)--End of spnspecLevel

on spnGloss changed val do 
	(
	--Define count Number
	matCounter01 = 1

	--Find out if its Layered
	try (matCounter01 = meditMaterials[14].count) 
	catch(
		meditMaterials[14].glossiness = val
	)--End of Catch

	if matCounter01 >= 1 then (
		for i=1 to (matCounter01) do
			(
				meditMaterials[14].materialList[i].glossiness = val
			)
		) else ()
	)--End of spnGloss

on spnSoften changed val do 
	(
	--Define count Number
	matCounter01 = 1

	--Find out if its Layered
	try (matCounter01 = meditMaterials[14].count) 
	catch(
		meditMaterials[14].Soften = val
	)--End of Catch

	if matCounter01 >= 1 then (
		for i=1 to (matCounter01) do
			(
				meditMaterials[14].materialList[i].Soften = val
			)
		) else ()
	)--End of spnSoften

on btnSelfP10 pressed do
(
fillamount = spnselfill.value
if fillamount < 100 then
	(
	val = fillamount + 10
		if val < 100 then
			(
			--Define count Number
			matCounter01 = 1

			--Find out if its Layered
			try (matCounter01 = meditMaterials[14].count) 
			catch(
				meditMaterials[14].selfIllumAmount = val
			)--End of Catch

			if matCounter01 >= 1 then (
				for i=1 to (matCounter01) do
				(
					meditMaterials[14].materialList[i].selfIllumAmount = val
				)
			) else ()
			spnselfill.value = val
			)
			else (
			val = 100
			--Define count Number
			matCounter01 = 1

			--Find out if its Layered
			try (matCounter01 = meditMaterials[14].count) 
			catch(
				meditMaterials[14].selfIllumAmount = val
			)--End of Catch

			if matCounter01 >= 1 then (
				for i=1 to (matCounter01) do
				(
					meditMaterials[14].materialList[i].selfIllumAmount = val
				)
			) else ()
			spnselfill.value = val
			)
	)	
else()
)--End of btnSelfP10

on btnSelfM10 pressed do
(
fillamount = spnselfill.value
if fillamount > 0 then
	(
	val = fillamount - 10
		if val > 0 then
			(
			--Define count Number
			matCounter01 = 1

			--Find out if its Layered
			try (matCounter01 = meditMaterials[14].count) 
			catch(
				meditMaterials[14].selfIllumAmount = val
			)--End of Catch

			if matCounter01 >= 1 then (
				for i=1 to (matCounter01) do
				(
					meditMaterials[14].materialList[i].selfIllumAmount = val
				)
			) else ()
			spnselfill.value = val
			)
			else (
			val = 0
			--Define count Number
			matCounter01 = 1

			--Find out if its Layered
			try (matCounter01 = meditMaterials[14].count) 
			catch(
				meditMaterials[14].selfIllumAmount = val
			)--End of Catch

			if matCounter01 >= 1 then (
				for i=1 to (matCounter01) do
				(
					meditMaterials[14].materialList[i].selfIllumAmount = val
				)
			) else ()
			spnselfill.value = val
			)
	)	
else()
)--End of btnSelfM10

on btnSpecP10 pressed do
(
fillamount = spnspecLevel.value
if fillamount < 1000 then
	(
	val = fillamount + 10
		if val < 1000 then
			(
			--Define count Number
			matCounter01 = 1

			--Find out if its Layered
			try (matCounter01 = meditMaterials[14].count) 
			catch(
				meditMaterials[14].specularLevel = val
			)--End of Catch

			if matCounter01 >= 1 then (
				for i=1 to (matCounter01) do
				(
					meditMaterials[14].materialList[i].specularLevel = val
				)
			) else ()
			spnspecLevel.value = val
			)
			else (
			val = 1000
			--Define count Number
			matCounter01 = 1

			--Find out if its Layered
			try (matCounter01 = meditMaterials[14].count) 
			catch(
				meditMaterials[14].specularLevel = val
			)--End of Catch

			if matCounter01 >= 1 then (
				for i=1 to (matCounter01) do
				(
					meditMaterials[14].materialList[i].specularLevel = val
				)
			) else ()
			spnspecLevel.value = val
			)
	)	
else()
)--End of btnSpecP10

on btnSpecM10 pressed do
(
fillamount = spnspecLevel.value
if fillamount > 0 then
	(
	val = fillamount - 10
		if val > 0 then
			(
			--Define count Number
			matCounter01 = 1

			--Find out if its Layered
			try (matCounter01 = meditMaterials[14].count) 
			catch(
				meditMaterials[14].specularLevel = val
			)--End of Catch

			if matCounter01 >= 1 then (
				for i=1 to (matCounter01) do
				(
					meditMaterials[14].materialList[i].specularLevel = val
				)
			) else ()
			spnspecLevel.value = val
			)
			else (
			val = 0
			--Define count Number
			matCounter01 = 1

			--Find out if its Layered
			try (matCounter01 = meditMaterials[14].count) 
			catch(
				meditMaterials[14].specularLevel = val
			)--End of Catch

			if matCounter01 >= 1 then (
				for i=1 to (matCounter01) do
				(
					meditMaterials[14].materialList[i].specularLevel = val
				)
			) else ()
			spnspecLevel.value = val
			)
	)	
else()
)--End of btnSpecM10

on btnGlossP10 pressed do
(
fillamount = spnGloss.value
if fillamount < 1000 then
	(
	val = fillamount + 10
		if val < 1000 then
			(
			--Define count Number
			matCounter01 = 1

			--Find out if its Layered
			try (matCounter01 = meditMaterials[14].count) 
			catch(
				meditMaterials[14].glossiness = val
			)--End of Catch

			if matCounter01 >= 1 then (
				for i=1 to (matCounter01) do
				(
					meditMaterials[14].materialList[i].glossiness = val
				)
			) else ()
			spnGloss.value = val
			)
			else (
			val = 1000
			--Define count Number
			matCounter01 = 1

			--Find out if its Layered
			try (matCounter01 = meditMaterials[14].count) 
			catch(
				meditMaterials[14].glossiness = val
			)--End of Catch

			if matCounter01 >= 1 then (
				for i=1 to (matCounter01) do
				(
					meditMaterials[14].materialList[i].glossiness = val
				)
			) else ()
			spnGloss.value = val
			)
	)	
else()
)--End of btnGlossP10

on btnGlossM10 pressed do
(
fillamount = spnGloss.value
if fillamount > 0 then
	(
	val = fillamount - 10
		if val > 0 then
			(
			--Define count Number
			matCounter01 = 1

			--Find out if its Layered
			try (matCounter01 = meditMaterials[14].count) 
			catch(
				meditMaterials[14].glossiness = val
			)--End of Catch

			if matCounter01 >= 1 then (
				for i=1 to (matCounter01) do
				(
					meditMaterials[14].materialList[i].glossiness = val
				)
			) else ()
			spnGloss.value = val
			)
			else (
			val = 0
			--Define count Number
			matCounter01 = 1

			--Find out if its Layered
			try (matCounter01 = meditMaterials[14].count) 
			catch(
				meditMaterials[14].glossiness = val
			)--End of Catch

			if matCounter01 >= 1 then (
				for i=1 to (matCounter01) do
				(
					meditMaterials[14].materialList[i].glossiness = val
				)
			) else ()
			spnGloss.value = val
			)
	)	
else()
)--End of btnGlossM10

on btnSoftP10 pressed do
(
fillamount = spnSoften.value
if fillamount < 1 then
	(
	val = fillamount + .5
		if val < 1 then
			(
			--Define count Number
			matCounter01 = 1

			--Find out if its Layered
			try (matCounter01 = meditMaterials[14].count) 
			catch(
				meditMaterials[14].Soften = val
			)--End of Catch

			if matCounter01 >= 1 then (
				for i=1 to (matCounter01) do
				(
					meditMaterials[14].materialList[i].Soften = val
				)
			) else ()
			spnSoften.value = val
			)
			else (
			val = 1
			--Define count Number
			matCounter01 = 1

			--Find out if its Layered
			try (matCounter01 = meditMaterials[14].count) 
			catch(
				meditMaterials[14].Soften = val
			)--End of Catch

			if matCounter01 >= 1 then (
				for i=1 to (matCounter01) do
				(
					meditMaterials[14].materialList[i].Soften = val
				)
			) else ()
			spnSoften.value = val
			)
	)	
else()
)--End of btnSoftP10

on btnSoftM10 pressed do
(
fillamount = spnSoften.value
if fillamount > 0  then
	(
	val = fillamount - .5
		if val > 0 then
			(
			--Define count Number
			matCounter01 = 1

			--Find out if its Layered
			try (matCounter01 = meditMaterials[14].count) 
			catch(
				meditMaterials[14].Soften = val
			)--End of Catch

			if matCounter01 >= 1 then (
				for i=1 to (matCounter01) do
				(
					meditMaterials[14].materialList[i].Soften = val
				)
			) else ()
			spnSoften.value = val
			)
			else (
			val = 0
			--Define count Number
			matCounter01 = 1

			--Find out if its Layered
			try (matCounter01 = meditMaterials[14].count) 
			catch(
				meditMaterials[14].Soften = val
			)--End of Catch

			if matCounter01 >= 1 then (
				for i=1 to (matCounter01) do
				(
					meditMaterials[14].materialList[i].Soften = val
				)
			) else ()
			spnSoften.value = val
			)
	)	
else()
)--End of btnSoftM10

on btnmatPreview pressed do
(
renderSceneDialog.close()
renderSceneDialog.open()
renderHeight = Rheight
renderWidth = Rwidth
renderSceneDialog.update()
renderSceneDialog.close()
max quick render
)
on btnMatEdit pressed do
(
if MatEditor.isOpen() == true
then
(MatEditor.Close())
else
(MatEditor.Open())
)
)--End of Material Section	





-----------------------------------------------------------------------------------------------------------
-- RolloutC Rollout
-----------------------------------------------------------------------------------------------------------
rollout rolloutC_rol "3 Point Lights"
	(
	on rolloutC_rol rolledUp state do
		(
		if rolloutC_rol.open == true then
			RendererDialog.rolloutC.height = 265
		else
			RendererDialog.rolloutC.height = 25
		RendererDialog.refreshmyrollouts()
		)

	on rolloutC_rol open do
		(
		if rolloutC_rol.open == true then
			RendererDialog.rolloutC.height = 265
		else
			RendererDialog.rolloutC.height = 25
		RendererDialog.refreshmyrollouts()
		)

	button btn3pScale2 "Scale 2x" pos:[2,3] width:46 height:17 toolTip: "Scales lighting setup down by half"
	button btn3pScaleHalf "Scale .5x" pos:[50,3] width:47 height:17 toolTip: "Scales lighting setup down by half"
	button btn3SelKey "Sel Key" pos:[2,22] width:46 height:17
	button btn3SelRim "Sel Rim" pos:[51,22] width:46 height:17
	button btn3SelFill "Sel Fill" pos:[2,41] width:46 height:17
	button btn3pSelAll "Sel All" pos:[51,41] width:46 height:17
	spinner spnkeyInt "Key Value: " pos:[4,61] width:93 height:16 range:[0,100,.35] controller:key3pIntensity
	button btnkeyInt1 "1" pos:[3,79] width:15 height:17
	button btnkeyInt2 "2" pos:[21,79] width:15 height:17
	button btnkeyInt3 "3" pos:[42,79] width:15 height:17
	button btnkeyInt4 "4" pos:[62,79] width:15 height:17
	button btnkeyInt5 "5" pos:[82,79] width:15 height:17
	spinner spnfillInt "Fill Value:  " pos:[5,98] width:91 height:16 range:[0,100,1.2] controller:fill3pIntensity
	button btnfillInt1 "1" pos:[3,116] width:15 height:17
	button btnfillInt2 "2" pos:[21,116] width:15 height:17
	button btnfillInt3 "3" pos:[42,116] width:15 height:17
	button btnfillInt4 "4" pos:[62,116] width:15 height:17
	button btnfillInt5 "5" pos:[82,116] width:15 height:17
	spinner spnrimInt "Rim Value: " pos:[4,136] width:93 height:16 range:[0,100,5] controller:rim3pIntensity
	button btnrimInt1 "1" pos:[3,153] width:15 height:17
	button btnrimInt2 "2" pos:[21,153] width:15 height:17
	button btnrimInt3 "3" pos:[42,153] width:15 height:17
	button btnrimInt4 "4" pos:[62,153] width:15 height:17
	button btnrimInt5 "5" pos:[82,153] width:15 height:17
	colorPicker cpshadColor "Shadow Color " pos:[3,173] width:93 height:15 color:(color 0 0 0)
	spinner spn3pShadDens "Shd. Dens." pos:[4,192] width:93 height:16 range:[0,100,3.5] 
	button btn3pPrev "Preview" pos:[2,210] width:45 height:18
	button btn3pDelAll "Del All" pos:[62,210] width:35 height:18

on cpshadColor changed new_col2 do $Fill3p.shadowColor = new_col2
on spn3pShadDens changed val do	$Fill3p.shadowMultiplier = val

--Key Intensity Adjust
on btnkeyInt1 pressed do 
(
spnkeyInt.value = 1
)
on btnkeyInt2 pressed do 
(
 spnkeyInt.value = 2
)
on btnkeyInt3 pressed do 
(
 spnkeyInt.value = 3
)
on btnkeyInt4 pressed do 
(
 spnkeyInt.value = 4
)
on btnkeyInt5 pressed do 
(
 spnkeyInt.value = 5
)

--Fill Intensity Adjust
on btnfillInt1 pressed do 
(
 spnfillInt.value = 1
)
on btnfillInt2 pressed do 
(
 spnfillInt.value = 2
)
on btnfillInt3 pressed do 
(
 spnfillInt.value = 3
)
on btnfillInt4 pressed do 
(
 spnfillInt.value = 4
)
on btnfillInt5 pressed do 
(
 spnfillInt.value = 5
)

--Rim Intensity Adjust
on btnrimInt1 pressed do 
(
 spnrimInt.value = 1
)
on btnrimInt2 pressed do 
(
 spnrimInt.value = 2
)
on btnrimInt3 pressed do 
(
 spnrimInt.value = 3
)
on btnrimInt4 pressed do 
(
 spnrimInt.value = 4
)
on btnrimInt5 pressed do 
(
 spnrimInt.value = 5
)

--Transform Light Positions
on btn3pScale2 pressed do
(
try(scale $3pointLightBase [2,2,2]) catch()
)

on btn3pScaleHalf pressed do
(
try(scale $3pointLightBase [.5,.5,.5]) catch()
)

--Selecting and Deleting
on btn3SelKey pressed do
(
try(select $Key3p) catch()
)

on btn3SelRim pressed do
(
try(select $Rim3p) catch()
)

on btn3SelFill pressed do
(
try(select $Fill3p) catch()
)

on btn3pSelAll pressed do
(
try(select $3pointLightBase) catch()
)

on btn3pDelAll pressed do
(
try(delete $Key3p) catch()
try(delete $Fill3p) catch()
try(delete $Rim3p) catch()
try(delete $3pointLightBase) catch()
try(delete $RendererGround) catch()
meditMaterials[15] = Standardmaterial ()
meditMaterials[15].name = "15 - Default"
)

on btn3pPrev pressed do 
(
renderSceneDialog.close()
renderSceneDialog.open()
renderHeight = Rheight
renderWidth = Rwidth
renderSceneDialog.update()
renderSceneDialog.close()
max quick render
)

)--End of 3 point Section


-----------------------------------------------------------------------------------------------------------
-- RolloutD Rollout
-----------------------------------------------------------------------------------------------------------
rollout rolloutD_rol "Faux GI Lights"
	(
	on rolloutD_rol rolledUp state do
		(
		if rolloutD_rol.open == true then
			RendererDialog.rolloutD.height = 170
		else
			RendererDialog.rolloutD.height = 25
		RendererDialog.refreshmyrollouts()
		)

	on rolloutD_rol open do
		(
		if rolloutD_rol.open == true then
			RendererDialog.rolloutD.height = 170
		else
			RendererDialog.rolloutD.height = 25
		RendererDialog.refreshmyrollouts()
		)
		
	button btnFGScale2 "Scale 2x" pos:[2,3] width:50 height:17  toolTip: "Scales lighting dome twice as large"
	button btnFGSelKey "Sel Key" pos:[55,3] width:42 height:17
	button btnFGScaleHalf "Scale .5x" pos:[2,21] width:50 height:17 toolTip: "Scales lighting dome down by half"
	button btnFGSelAll "Sel All" pos:[55,21] width:42 height:17
	spinner spnFGmainInt "Main Value:" pos:[9,40] width:88 height:16 range:[0,100,.3] controller:mainIntensity
	button btnmainInt1 ".1" pos:[3,58] width:15 height:17
	button btnmainInt2 ".2" pos:[21,58] width:15 height:17
	button btnmainInt3 ".3" pos:[42,58] width:15 height:17
	button btnmainInt4 ".4" pos:[62,58] width:15 height:17
	button btnmainInt5 ".5" pos:[82,58] width:15 height:17
	spinner spnFGkeyInt "Key Value: " pos:[9,78] width:88 height:16 range:[0,100,.5] controller:keyIntensity
	button btnFGkeyInt1 ".1" pos:[3,96] width:15 height:17
	button btnFGkeyInt2 ".2" pos:[21,96] width:15 height:17
	button btnFGkeyInt3 ".3" pos:[42,96] width:15 height:17
	button btnFGkeyInt4 ".4" pos:[62,96] width:15 height:17
	button btnFGkeyInt5 ".5" pos:[82,96] width:15 height:17
	button btnFGPrev "Preview" pos:[3,115] width:45 height:18
	button btnFGpDelAll "Del All" pos:[62,115] width:35 height:18 toolTip: "Deletes all lights created by Faux GI setup"

--Main Intensity Adjust
on btnmainInt1 pressed do 
(
 spnFGmainInt.value = .1
)
on btnmainInt2 pressed do 
(
 spnFGmainInt.value = .2
)
on btnmainInt3 pressed do 
(
 spnFGmainInt.value = .3
)
on btnmainInt4 pressed do 
(
 spnFGmainInt.value = .4
)
on btnmainInt5 pressed do 
(
 spnFGmainInt.value = .5
)

--Key Adjustments
on btnFGkeyInt1 pressed do
(
 spnFGkeyInt.value = .1
)
on btnFGkeyInt2 pressed do
(
 spnFGkeyInt.value = .2
)
on btnFGkeyInt3 pressed do
(
 spnFGkeyInt.value = .3
)
on btnFGkeyInt4 pressed do
(
 spnFGkeyInt.value = .4
)
on btnFGkeyInt5 pressed do
(
 spnFGkeyInt.value = .5
)

--Transform Light Positions
on btnFGScale2 pressed do 
(
try(scale $LightBase [2,2,2]) catch()
)

on btnFGScaleHalf pressed do 
(
try(scale $LightBase [.5,.5,.5]) catch()
)

on btnFGSelAll pressed do 
(
try(select $LightBase) catch()
)

on btnFGSelKey pressed do 
(
try(select $key) catch()
)

--Delete All
on btnFGpDelAll pressed do
(
try(
delete #($LightBase, $front, $frontright, $right, $backright, $backleft, $left, $frontleft, $topright, $topback, $topleft, $key) 
) catch()
)

--Preview
on btnFGPrev pressed do 
(
renderSceneDialog.close()
renderSceneDialog.open()
renderHeight = Rheight
renderWidth = Rwidth
renderSceneDialog.update()
renderSceneDialog.close()
max quick render
)


)--End of Faux GI section


-----------------------------------------------------------------------------------------------------------
-- RolloutE Rollout
-----------------------------------------------------------------------------------------------------------
rollout rolloutE_rol "Background"
	(
	on rolloutE_rol rolledUp state do
		(
		if rolloutE_rol.open == true then
			RendererDialog.rolloutE.height = 78
		else
			RendererDialog.rolloutE.height = 25
		RendererDialog.refreshmyrollouts()
		)

	on rolloutE_rol open do
		(
		if rolloutE_rol.open == true then
			RendererDialog.rolloutE.height = 78		
		else
			RendererDialog.rolloutE.height = 25
		RendererDialog.refreshmyrollouts()
		)

	button btnbgGrey "Grey" pos:[2,3] width:27 height:18
	button btnbgBlack "Black" pos:[30,3] width:32 height:18
	button btnbgWhite "White" pos:[64,3] width:35 height:18
	colorPicker cpbgCust "Cust:" pos:[50,24] width:48 height:17 color:(color 151 151 151) modal:false
	button btnbgPrev "Preview" pos:[2,24] width:45 height:18

on btnbgPrev pressed do 
(
renderSceneDialog.close()
renderSceneDialog.open()
renderHeight = Rheight
renderWidth = Rwidth
renderSceneDialog.update()
renderSceneDialog.close()
max quick render
)

on btnbgBlack pressed do 
	(
	backgroundColor = color 0 0 0
	)

on btnbgWhite pressed do 
	(
	backgroundColor = color 255 255 255
	)

on btnbgGrey pressed do 
	(
	backgroundColor = color 151 151 151
	)

--Custom Color Picker for Background color
on cpbgCust changed new_col2 do
	(
	backgroundColor = new_col2
	)


)--End of Background Section


-----------------------------------------------------------------------------------------------------------
-- RolloutF Rollout
-----------------------------------------------------------------------------------------------------------
rollout rolloutF_rol "Environment"
	(
	on rolloutF_rol rolledUp state do
		(
		if rolloutF_rol.open == true then
			RendererDialog.rolloutF.height = 95
		else
			RendererDialog.rolloutF.height = 25
		RendererDialog.refreshmyrollouts()
		)

	on rolloutF_rol open do
		(
		if rolloutF_rol.open == true then
			RendererDialog.rolloutF.height = 95
		else
			RendererDialog.rolloutF.height = 25
		RendererDialog.refreshmyrollouts()
		)

	colorPicker cpevglobalLight "Gl. Lighting Tint:" pos:[2,3] width:97 height:18 color:(color 255 255 255)
	checkbox chkevtextMap "Texture Mapping" pos:[2,22] width:106 height:18 checked:true
	button btnEVPrev "Preview" pos:[1,41] width:43 height:18
	button btnEvDialog "Env.Dialog" pos:[46,41] width:55 height:18 toolTip: "Opens Environment and Effects Dialog Window"
	
on cpevglobalLight changed new_col do
	(
	lightTintColor = new_col
	)

on chkevtextMap changed state do
	(
	texture = chkevtextMap.state as string
	if texture == "false" then
	 renderers.production.mapping = false
	else
	 renderers.production.mapping = true
	)

on btnEVPrev pressed do 
(
renderSceneDialog.close()
renderSceneDialog.open()
renderHeight = Rheight
renderWidth = Rwidth
renderSceneDialog.update()
renderSceneDialog.close()
max quick render
)

on btnEvDialog pressed do
(
if envEffectsDialog.isOpen() == true
then
(envEffectsDialog.Close())
else
(envEffectsDialog.Open())
)--End of btnEvDialog


)-- End of Environ Section


-----------------------------------------------------------------------------------------------------------
-- RolloutG Rollout
-----------------------------------------------------------------------------------------------------------
rollout rolloutG_rol "Output"
	(
	on rolloutG_rol rolledUp state do
		(
		if rolloutG_rol.open == true then
			RendererDialog.rolloutG.height = 114
		else
			RendererDialog.rolloutG.height = 25
		RendererDialog.refreshmyrollouts()
		)

	on rolloutG_rol open do
		(
		if rolloutG_rol.open == true then
			RendererDialog.rolloutG.height = 114
		else
			RendererDialog.rolloutG.height = 25
		RendererDialog.refreshmyrollouts()
		)

	button btnop140 "140x105" pos:[2,3] width:48 height:17
	button btnop200 "200x200" pos:[53,3] width:48 height:17
	button btnop320 "320x240" pos:[2,21] width:48 height:17
	button btnop640 "640x480" pos:[53,21] width:48 height:17
	button btnopCust "Custom" pos:[2,40] width:48 height:17
	button btnop720 "720x480" pos:[53,40] width:48 height:17


on btnop140 pressed do 
(
Rheight = 105
Rwidth = 140
renderSceneDialog.close()
renderSceneDialog.open()
renderHeight = 105
renderWidth = 140
renderSceneDialog.update()
renderSceneDialog.close()
max quick render
)

on btnop320 pressed do 
(
Rheight = 240
Rwidth = 320
renderSceneDialog.close()
renderSceneDialog.open()
renderHeight = 240
renderWidth = 320
renderSceneDialog.update()
renderSceneDialog.close()
max quick render
)

on btnop200 pressed do 
(
Rheight = 200
Rwidth = 200
renderSceneDialog.close()
renderSceneDialog.open()
renderHeight = 200
renderWidth = 200
renderSceneDialog.update()
renderSceneDialog.close()
max quick render
)

on btnop640 pressed do 
(
Rheight = 480
Rwidth = 640
renderSceneDialog.close()
renderSceneDialog.open()
renderHeight = 480
renderWidth = 640
renderSceneDialog.update()
renderSceneDialog.close()
max quick render
)

on btnop720 pressed do 
(
Rheight = 480
Rwidth = 720
renderSceneDialog.close()
renderSceneDialog.open()
renderHeight = 480
renderWidth = 720
renderSceneDialog.update()
renderSceneDialog.close()
max quick render
)

--------------------
--Custom Render Area
--------------------
editText edtopWidth "W:" pos:[2,62] width:48 height:16 text:"140"
editText edtopHeight "H:" pos:[56,62] width:46 height:16 text:"105"

on edtopWidth changed txt do
	(
	xxRwidth = txt
	Rwidth = xxRwidth as integer
	)

on edtopHeight changed txt do
	(
	xxRheight = txt
	Rheight = xxRheight as integer
	)

on btnopCust pressed do 
(
renderSceneDialog.close()
renderSceneDialog.open()
renderHeight = Rheight
renderWidth = Rwidth
renderSceneDialog.update()
renderSceneDialog.close()
max quick render
)

--End of Output Section
)


-----------------------------------------------------------------------------------------------------------
-- RolloutH Rollout
-----------------------------------------------------------------------------------------------------------
rollout rolloutH_rol "Final Render"
	(
	on rolloutH_rol rolledUp state do
		(
		if rolloutH_rol.open == true then
			RendererDialog.rolloutH.height = 131
		else
			RendererDialog.rolloutH.height = 25
		RendererDialog.refreshmyrollouts()
		)

	on rolloutH_rol open do
		(
		if rolloutH_rol.open == true then
			RendererDialog.rolloutH.height = 131
		else
			RendererDialog.rolloutH.height = 25
		RendererDialog.refreshmyrollouts()
		)

	button btnSafeFrame "SafeFrame" pos:[2,2] width:55 height:16 toolTip: "Toggle ON/Off Safe Frames"
	button btnCleanBG "CleanBG" pos:[58,2] width:46 height:16 toolTip: "Deletes BG Color, Tint Anim Curves"
	radioButtons rdoRenderType "       Render Type" pos:[1,20] width:151 height:30 labels:#("Anim", "Frame") default:1 columns:2
	label lblbreaker8 "---------------------------------" pos:[2,50] width:126 height:9
	label lblRenderAs "Render As:" pos:[27,60] width:60 height:17
	button btnrendJPG "JPG" pos:[4,77] width:27 height:18
	button btnrendBMP "BMP" pos:[38,77] width:27 height:18
	button btnrendGIF "GIF" pos:[74,77] width:27 height:18 toolTip: "Requires ImageMagick to be Installed"

on btnSafeFrame pressed do
(
framer = displaySafeFrames
print framer
if framer == false then 
(
displaySafeFrames = true
actionMan.executeAction 0 "50026"  -- Tools: Maximize Viewport Toggle
redrawViews()
actionMan.executeAction 0 "50026"  -- Tools: Maximize Viewport Toggle
)
else
(
displaySafeFrames = false
actionMan.executeAction 0 "50026"  -- Tools: Maximize Viewport Toggle
redrawViews()
actionMan.executeAction 0 "50026"  -- Tools: Maximize Viewport Toggle
)--End of if then
)--End of btnSafeFrame

on btnCleanBG pressed do
(
deleteKeys backGroundColorController
deleteKeys lightTintColorController
)--End of btnCleanBG



on rdoRenderType changed stat do
(
	if renderType == 0 then
	(
	renderType = 1
	)
	else
	(
	renderType = 0
	)
)

on btnrendJPG pressed do 
(
if renderType == 0 then
(
	filenamer = (getFileNameFile maxFileName + ".jpg")
	filedire = "C:\\Renderer\\Anims\\JPG\\"
	myoutput = (filedire + filenamer) 
	makeDir "C:\\Renderer"
	makeDir "C:\\Renderer\\Anims"
	makeDir "C:\\Renderer\\Anims\\JPG"
	render framerange:#active nthframe:1 outputSize:[Rwidth,Rheight] pixelaspect:1 outputfile:myoutput
	try(deleteFile "C:\\Renderer\\temp.max") catch()
)
else
(
	framer = sliderTime as string
	filenamer = (getFileNameFile maxFileName + framer + ".jpg")
	filedire = "C:\\Renderer\\Singles\\JPG\\"
	myoutput = (filedire + filenamer) 
	makeDir "C:\\Renderer"
	makeDir "C:\\Renderer\\Singles"
	makeDir "C:\\Renderer\\Singles\\JPG"
	render outputSize:[Rwidth,Rheight] pixelaspect:1 outputfile:myoutput
	try(deleteFile "C:\\Renderer\\temp.max") catch()
)
)

on btnrendBMP pressed do 
(
if renderType == 0 then
(
	filenamer = (getFileNameFile maxFileName + ".bmp")
	filedire = "C:\\Renderer\\Anims\\BMP\\"
	myoutput = (filedire + filenamer) 
	makeDir "C:\\Renderer"
	makeDir "C:\\Renderer\\Anims"
	makeDir "C:\\Renderer\\Anims\\BMP"
	render framerange:#active nthframe:1 outputSize:[Rwidth,Rheight] pixelaspect:1 outputfile:myoutput
	try(deleteFile "C:\\Renderer\\temp.max") catch()
)
else
(
	framer = sliderTime as string
	filenamer = (getFileNameFile maxFileName + framer + ".bmp")
	filedire = "C:\\Renderer\\Singles\\BMP\\"
	myoutput = (filedire + filenamer) 
	makeDir "C:\\Renderer"
	makeDir "C:\\Renderer\\Singles"
	makeDir "C:\\Renderer\\Singles\\BMP"
	render outputSize:[Rwidth,Rheight] pixelaspect:1 outputfile:myoutput
	try(deleteFile "C:\\Renderer\\temp.max") catch()
)
)

on btnrendGIF pressed do 
(
	try(for f in getFiles "C:\\Renderer\\emptyrenders\\*.bmp" do deleteFile f) catch()
	filenamer = (getFileNameFile maxFileName + ".bmp")
	filedire = "C:\\Renderer\\emptyrenders\\"
	myoutput = (filedire + filenamer) 
	makeDir "C:\\Renderer"
	makeDir "C:\\GIFs"
	makeDir "C:\\Renderer\\emptyrenders"
	makeDir "C:\\Renderer\\GIFs"
	render framerange:#active nthframe:nframe outputSize:[Rwidth,Rheight] pixelaspect:1 outputfile:myoutput
	gifnamer = (getFileNameFile maxFileName + ".gif")
	new_gif_path = "C:\\Renderer\\GIFs\\"
	old_gif_path = "C:\\GIFs\\"
	imgmagik_path = "C:\\ImageMagick\\imconvert.exe -limit memory 1024 c:\\Renderer\\emptyrenders\\"
	fileall = ("*.bmp")
	DOSCommand( imgmagik_path + fileall + " " + new_gif_path + gifnamer )
	DOSCommand( imgmagik_path + fileall + " " + old_gif_path + gifnamer )
	for f in getFiles "C:\\Renderer\\emptyrenders\\*.bmp" do deleteFile f
	deleteFile "C:\\Renderer\\temp.max"
)

--End of Final Render Rollout
)

-----------------------------------------------------------------------------------------------------------
-- RolloutI Rollout
-----------------------------------------------------------------------------------------------------------
rollout rolloutI_rol "Tweeks"
	(
	on rolloutI_rol rolledUp state do
		(
		if rolloutI_rol.open == true then
			RendererDialog.rolloutI.height = 98
		else
			RendererDialog.rolloutI.height = 25
		RendererDialog.refreshmyrollouts()
		)

	on rolloutI_rol open do
		(
		if rolloutI_rol.open == true then
			RendererDialog.rolloutI.height = 98
		else
			RendererDialog.rolloutI.height = 25
		RendererDialog.refreshmyrollouts()
		)

	editText edtNthFrame "GIF Nth Frame:" fieldWidth:20 labelOnLeft:true pos:[2,6] height:17 enabled:true text:"3"
	button btnGIF1 "1" pos:[3,25] width:15 height:17 toolTip: "GIF has every frame of anim"
	button btnGIF2 "2" pos:[21,25] width:15 height:17 toolTip: "GIF has every other frame of anim"
	button btnGIF3 "3" pos:[42,25] width:15 height:17 toolTip: "GIF has every thrid frame of anim"
	button btnGIF4 "4" pos:[62,25] width:15 height:17 toolTip: "GIF has every forth frame of anim"
	button btnGIF5 "5" pos:[82,25] width:15 height:17 toolTip: "GIF has every fifth frame of anim"
	button butAvatText "Convert Avat. Text." pos:[2,45] width:97 height:17  toolTip: "Based off Female from HumanRef Script"
	
on edtNthFrame entered txt do
(
try(
innframe = txt
nframe = innframe as integer
)
catch()
)

on btnGIF1 pressed do
(
nframe = 1
edtNthFrame.text= "1"
)--End of btnGIF1

on btnGIF2 pressed do
(
nframe = 2
edtNthFrame.text= "2"
)--End of btnGI2

on btnGIF3 pressed do
(
nframe = 3
edtNthFrame.text= "3"
)--End of btnGIF3

on btnGIF4 pressed do
(
nframe = 4
edtNthFrame.text= "4"
)--End of btnGIF4

on btnGIF5 pressed do
(
nframe = 5
edtNthFrame.text= "5"
)--End of btnGIF5

on butAvatText pressed do
(
try(
meditMaterials[16] = $Female_stand_in.material
meditMaterials[16].material1.shaderType = 1
meditMaterials[16].material1.selfIllumAmount = 80
meditMaterials[16].materialList[2].shaderType = 1
meditMaterials[16].materialList[2].selfIllumAmount = 80
meditMaterials[16].materialList[3].shaderType = 1
meditMaterials[16].materialList[3].selfIllumAmount = 80
) catch()
)
--end of Tweeks Section
)

-----------------------------------------------------------------------------------------------------------
-- RolloutJ Rollout
-----------------------------------------------------------------------------------------------------------
rollout rolloutJ_rol "Support"
	(
	on rolloutJ_rol rolledUp state do
		(
		if rolloutJ_rol.open == true then
			RendererDialog.rolloutJ.height = 82
		else
			RendererDialog.rolloutJ.height = 25
		RendererDialog.refreshmyrollouts()
		)

	on rolloutJ_rol open do
		(
		if rolloutJ_rol.open == true then
			RendererDialog.rolloutJ.height = 82
		else
			RendererDialog.rolloutJ.height = 25
		RendererDialog.refreshmyrollouts()
		)

	button btnspInfo "Info" pos:[2,4] width:26 height:18
	button btnspGetGif "Get GIF Tool" pos:[32,4] width:68 height:18
	button btnspDir "Directories" pos:[2,24] width:57 height:18
	button btnspUpdate "Update" pos:[61,24] width:40 height:18


on btnspUpdate pressed do
(
	rollout Updated "Newest Version" width:200 height:120
	(
		label lab00 "==CURRENTLY DISABLED, EDIT SCRIPT TO REANABLE==" 
		button updateGIF "Update..." height: 16
		label lab01 "--New script in C:\Renderer\Updates--" 
		label lab02 "Please move to your scripts directory" 
		label lab03 "Overwrite existing Renderer.mcr" 
		label lab04 "---Then Restart Max---" 
		on updateGIF pressed do 
		(
		try
		(
		makeDir "C:\\Renderer"
		makeDir "C:\\Renderer\\Updates"
		--newMe = "XCOPY V:\\...\\Renderer.mcr C:\\Renderer\\Updates /e /i /k /y"
		--DOSCommand( newMe )
		)
		catch()
		)
	)
	createDialog Updated
)

on btnspGetGif pressed do
(
	rollout getmaker2 "Installing GIFMaker" width:340 height:175
	(
	label lab099 "ImageMagick in C:"  
	label lab990 "----------------------------------------------------------------------------------------------------------" pos:[7,20] 
	label lab991 "1.  Install to c:\ImageMagick" pos:[7,35]
	label lab992 "2.  For Additional Tasks, just check, Update excutable search path" pos:[7,50]
	label lab993 "3.  Finish the rest of the installation with default settings" pos:[7,65]
	label lab9932 "4.  Go to c:\ImageMagick and rename 'convert' to 'imconvert'" pos:[7,80]
	label lab994 "----------------------------------------------------------------------------------------------------------" pos:[7,95]
	label lab995 "This only needs to be done once." 
	label lab000 "==CURRENTLY DISABLED, EDIT SCRIPT TO REANABLE==" 
	button getMaker "Get Maker" width:65 height:16 
	on getMaker pressed do 
	(
	try
	(
	--copyMe = "XCOPY V:\\...\\ImageMagick.exe C:\\ /E /I /y"
	--DOSCommand( copyMe )
	)
	catch()
	)  
	)
	createDialog getmaker2
)

on btnspInfo pressed do
(
	rollout info "Script Information" width:115 height:80
	(
 		label lab101 "The Renderer" 
		label lab102 "version 2.02" 
		label lab103 "Written by Kiel Figgins" 
		hyperLink website "www.3dfiggins.com" color: (color 205 50 85) address: "http://www.3dfiggins.com"
	)
	createDialog info

)

on btnspDir pressed do
(
	rollout directlink "Directories" width:160 height:80
	(
 		label lab101 "File and Renders" 
		label lab102 "-- C:\Renderer --" 
		label lab103 "ImageMagick Installer" 
		label lab104 "-- C:\ --" 
	)
	createDialog directlink
)

--End of Support Section
)


-----------------------------------------------------------------------------------------------------------
-- MAIN Rollout
-----------------------------------------------------------------------------------------------------------
rollout RendererDialog "Renderer 2.02"
	( 
	label lbloptional " ----( Optional )----" pos:[14,0] width:143 height:15
	label lblselMesh "Select Mesh, then:" pos:[10,13] width:163 height:15
	button btnconvMat "Convert Material" pos:[10,27] width:86 height:18 toolTip: "Converts selected geo material to be used with The Renderer"
	label lblcreateLights "Lighting Scheme:" pos:[13,45] width:103 height:15
	button btn3point "3 Point" pos:[11,60] width:38 height:18 toolTip: "Key, Fill, Rim lights with Ground plane"
	button btnfauxGI "Faux GI" pos:[54,60] width:44 height:18 toolTip: "Dome Array of point lights, with a Key"

on btnconvMat pressed do
(
--Converting HumanRef Avatar Material to something decent to render
try(
meditMaterials[16] = $Female_stand_in.material
meditMaterials[16].material1.shaderType = 1
meditMaterials[16].material1.selfIllumAmount = 100
meditMaterials[16].materialList[2].shaderType = 1
meditMaterials[16].materialList[2].selfIllumAmount = 100
meditMaterials[16].materialList[3].shaderType = 1
meditMaterials[16].materialList[3].selfIllumAmount = 100
meditMaterials[16].materialList[4].shaderType = 1
meditMaterials[16].materialList[4].selfIllumAmount = 100
) catch()
if $selection.count	== 1 then
(
--Expand Material Options
		if rolloutB_rol.open = true then
			RendererDialog.rolloutB.height = 170
		else
			RendererDialog.rolloutB.height = 25
		RendererDialog.refreshmyrollouts()
--End of Expanding

makeDir "C:\\Renderer"
makeDir "C:\\Renderer\\Scenes"
makeDir "C:\\Renderer\\Scenes\\BeforeMaterialChange"
makeDir "C:\\Renderer\\Scenes\\AfterMaterialChange"

--Save Backup Copy of File before material change
saver = maxFileName
saveMaxFile ("C:\\Renderer\\Scenes\\BeforeMaterialChange\\"+ saver)

--Convert Material
materialTest = $.material
if materialTest == undefined then
(
	--Define count Number
	matCounter01 = 1

	--Assign to slot
	$.material = meditMaterials[14]

	--Find out if its Layered
	try (matCounter01 = meditMaterials[14].count) 
	catch(
		meditMaterials[14] = $.material
		meditMaterials[14].shaderType = 1
		meditMaterials[14].selfIllumAmount = 80
	)--End of Catch

	if matCounter01 >= 1 then (
		for i=1 to (matCounter01) do
			(
				meditMaterials[14].materialList[i].shaderType = 1
				meditMaterials[14].materialList[i].selfIllumAmount = 80
			)
		) else ()
)
else
(
	--Define count Number
	matCounter01 = 1

	--Assign to Slot
	meditMaterials[14] = $.material

	--Find out if its Layered
	try (matCounter01 = meditMaterials[14].count) 
	catch(
		meditMaterials[14].shaderType = 1
		meditMaterials[14].selfIllumAmount = 80
	)--End of Catch

	if matCounter01 >= 1 then (
		for i=1 to (matCounter01) do
			(
				meditMaterials[14].materialList[i].shaderType = 1
				meditMaterials[14].materialList[i].selfIllumAmount = 80
			)
	) else ()
)
clearSelection()

--Saved  Copy of File after material change
saver1 = maxFileName
saveMaxFile ("C:\\Renderer\\Scenes\\AfterMaterialChange\\"+ saver1)

print "Backup Files Saved in C \ Renderer \ Scenes"
)
else
(
	rollout oneMesh "Select Again" width:140 height:70
	(
		label lab01x "Please select only 1 (one)" 
		label lab02x "object as your Mesh"
		button btnClose "Close"
		
		on btnClose pressed do
			(
			destroyDialog oneMesh
			clearSelection()
			)
	)
	createDialog oneMesh
)
)

on btn3point pressed do
(
--Expand 3 point Options
		if rolloutC_rol.open = true then
			RendererDialog.rolloutC.height = 265
		else
			RendererDialog.rolloutC.height = 25
		RendererDialog.refreshmyrollouts()
--End of Expanding

--3 point lighting

--Create Plane, material, apply
Plane length:2000 width:2000 pos:[0,0,0] name:"RendererGround"
meditMaterials[15].name = "RendererGroundPlane"
meditMaterials[15] = MatteShadow ()
$RendererGround.material = meditMaterials[15]
$RendererGround.xray = true

--Create Lights
Point pos:[0,0,0] name:"3pointLightBase"
Omnilight name:"Fill3p" rgb:(color 255 255 255) multiplier:1.2 pos:[0,0,650] castShadows:on shadowColor:(color 65 65 65) shadowMultiplier:0.35 mapsize:1024 samplerange:6
Omnilight name:"Rim3p" rgb:(color 255 255 255) multiplier:5.0 pos:[0,-100,-70]
Omnilight name:"Key3p" rgb:(color 255 255 255) multiplier:3.5 pos:[0,-250,200]

--Spinner Controls
$Key3p.multiplier.controller=key3pIntensity
$Fill3p.multiplier.controller=fill3pIntensity
$Rim3p.multiplier.controller=rim3pIntensity

--Parenting and Cleanup
$Key3p.parent = $3pointLightBase
$Fill3p.parent = $3pointLightBase
$Rim3p.parent = $3pointLightBase
hide $3pointLightBase
clearSelection()
hideByCategory.all()
hideByCategory.geometry = false
hideByCategory.lights = false

)

on btnfauxGI pressed do
(
--Expand Faux GI Options
		if rolloutD_rol.open = true then
			RendererDialog.rolloutD.height = 170
		else
			RendererDialog.rolloutD.height = 25
		RendererDialog.refreshmyrollouts()
--End of Expanding

--Create Lighting
Point pos:[0,0,0] name:"LightBase"
Omnilight name:"front" rgb:(color 255 255 255) multiplier:0.3 pos:[0,-200,140]
Omnilight name:"frontright" rgb:(color 255 255 255) multiplier:0.3 pos:[-160,-150,140]
Omnilight name:"right" rgb:(color 255 255 255) multiplier:0.3 pos:[-250,0,140]
Omnilight name:"backright" rgb:(color 255 255 255) multiplier:0.3 pos:[-195,168,140]
Omnilight name:"backleft" rgb:(color 255 255 255) multiplier:0.3 pos:[167,170,140]
Omnilight name:"left" rgb:(color 255 255 255) multiplier:0.3 pos:[248.184,0,140]
Omnilight name:"frontleft" rgb:(color 255 255 255) multiplier:0.3 pos:[151.817,-116,140]
Omnilight name:"topright" rgb:(color 255 255 255) multiplier:0.3 pos:[-255,0,315]
Omnilight name:"topback" rgb:(color 255 255 255) multiplier:0.3 pos:[0,250,315]
Omnilight name:"topleft" rgb:(color 255 255 255) multiplier:0.3 pos:[220,0,315]
Omnilight name:"key" rgb:(color 255 255 255) multiplier:0.5 pos:[0,-140,430]
$key.multiplier.controller=keyIntensity
$front.multiplier.controller=mainIntensity
$frontright.multiplier.controller=mainIntensity
$right.multiplier.controller=mainIntensity
$backright.multiplier.controller=mainIntensity
$backleft.multiplier.controller=mainIntensity
$left.multiplier.controller=mainIntensity
$frontleft.multiplier.controller=mainIntensity
$topright.multiplier.controller=mainIntensity
$topback.multiplier.controller=mainIntensity
$topleft.multiplier.controller=mainIntensity
$front.parent = $LightBase
$frontright.parent = $LightBase
$backright.parent = $LightBase
$backleft.parent = $LightBase
$left.parent = $LightBase
$frontleft.parent = $LightBase
$topright.parent = $LightBase
$topback.parent = $LightBase
$topleft.parent = $LightBase
$key.parent = $LightBase
$right.parent = $LightBase
hide $LightBase
clearSelection()
hideByCategory.all()
hideByCategory.geometry = false
hideByCategory.lights = false

)


	-----------------------------------------------------------------------------------------------------------
	-- Rollouts:
	-----------------------------------------------------------------------------------------------------------

	subrollout rolloutA "Camera"         width:118 height:24 offset:[-12,0]
	subrollout rolloutB "Materials"      width:118 height:24 offset:[-12,0]
	subrollout rolloutC "3 Point Lights" width:118 height:24 offset:[-12,0]
	subrollout rolloutD "Faux GI Lights" width:118 height:24 offset:[-12,0]
	subrollout rolloutE "Background"     width:118 height:24 offset:[-12,0]
	subrollout rolloutF "Environment"    width:118 height:24 offset:[-12,0]
	subrollout rolloutG "Output"         width:118 height:24 offset:[-12,0]
	subrollout rolloutH "Final Render"   width:118 height:24 offset:[-12,0]
	subrollout rolloutI "Tweeks"         width:118 height:24 offset:[-12,0]
	subrollout rolloutJ "Support"        width:118 height:24 offset:[-12,0]


	-----------------------------------------------------------------------------------------------------------
	-- Functions:
	-----------------------------------------------------------------------------------------------------------

	/*
	# Function     : refreshmyrollouts
	# Description  : Resizes and Repositions subrollouts
	# Parameters : 
	# Returns     : 
	*/
	fn refreshmyrollouts =
		(
		try(
		local rolloutAmove = 0
		local rolloutBmove = 0
		local rolloutCmove = 0
		local rolloutDmove = 0
		local rolloutEmove = 0
		local rolloutFmove = 0
		local rolloutGmove = 0
		local rolloutHmove = 0
		local rolloutImove = 0
		local rolloutJmove = 0
		if RendererDialog.rolloutA.rolloutA_rol.open == true then rolloutAmove += 82
		if RendererDialog.rolloutB.rolloutB_rol.open == true then rolloutBmove += 144
		if RendererDialog.rolloutC.rolloutC_rol.open == true then rolloutCmove += 242
		if RendererDialog.rolloutD.rolloutD_rol.open == true then rolloutDmove += 144
		if RendererDialog.rolloutE.rolloutE_rol.open == true then rolloutEmove += 52
		if RendererDialog.rolloutF.rolloutF_rol.open == true then rolloutFmove += 68
		if RendererDialog.rolloutG.rolloutG_rol.open == true then rolloutGmove += 87
		if RendererDialog.rolloutH.rolloutH_rol.open == true then rolloutHmove += 105
		if RendererDialog.rolloutI.rolloutI_rol.open == true then rolloutImove += 76 
		if RendererDialog.rolloutJ.rolloutJ_rol.open == true then rolloutJmove += 54

		RendererDialog.rolloutA.pos = [1,83]
		RendererDialog.rolloutB.pos = [1,(113 + rolloutAmove)]
		RendererDialog.rolloutC.pos = [1,(143 + rolloutAmove + rolloutBmove)]
		RendererDialog.rolloutD.pos = [1,(173 + rolloutAmove + rolloutBmove + rolloutCmove)]
		RendererDialog.rolloutE.pos = [1,(203 + rolloutAmove + rolloutBmove + rolloutCmove + rolloutDmove)]
		RendererDialog.rolloutF.pos = [1,(233 + rolloutAmove + rolloutBmove + rolloutCmove + rolloutDmove + rolloutEmove)]
		RendererDialog.rolloutG.pos = [1,(263 + rolloutAmove + rolloutBmove + rolloutCmove + rolloutDmove + rolloutEmove + rolloutFmove)]
		RendererDialog.rolloutH.pos = [1,(293 + rolloutAmove + rolloutBmove + rolloutCmove + rolloutDmove + rolloutEmove + rolloutFmove + rolloutGmove)]
		RendererDialog.rolloutI.pos = [1,(323 + rolloutAmove + rolloutBmove + rolloutCmove + rolloutDmove + rolloutEmove + rolloutFmove + rolloutGmove + rolloutHmove)]
		RendererDialog.rolloutJ.pos = [1,(353 + rolloutAmove + rolloutBmove + rolloutCmove + rolloutDmove + rolloutEmove + rolloutFmove + rolloutGmove + rolloutHmove + rolloutImove)]	
		)
		catch()
		)

	-----------------------------------------------------------------------------------------------------------
	-- Rollout events
	-----------------------------------------------------------------------------------------------------------


	on RendererDialog open do
		(
		yourPath = getFilenamePath maxFilePath
		yourName = getFilenameFile maxFileName
		viewSetupStart = viewport.getLayout()
		animButtonState = false
		lightTintColor = (color 255 255 255)
		backgroundColor = [151,151,151]
		addsubrollout RendererDialog.rolloutA rolloutA_rol rolledup:true
		addsubrollout RendererDialog.rolloutB rolloutB_rol rolledup:true
		addsubrollout RendererDialog.rolloutC rolloutC_rol rolledup:true
		addsubrollout RendererDialog.rolloutD rolloutD_rol rolledup:true
		addsubrollout RendererDialog.rolloutE rolloutE_rol rolledup:false
		addsubrollout RendererDialog.rolloutF rolloutF_rol rolledup:true
		addsubrollout RendererDialog.rolloutG rolloutG_rol rolledup:false
		addsubrollout RendererDialog.rolloutH rolloutH_rol rolledup:false
		addsubrollout RendererDialog.rolloutI rolloutI_rol rolledup:true
		addsubrollout RendererDialog.rolloutJ rolloutJ_rol rolledup:true
		makeDir "C:\\Renderer"
		if maxFileName == "" then saveMaxFile "C:\\Renderer\\temp.max" else print "File Saved"
		unfreeze objects
		clearSelection()
		hideByCategory.all()
		hideByCategory.geometry = false
		hideByCategory.lights = false
		viewcount = viewport.numViews
		if viewcount == 1 then
			(
				displaySafeFrames = true
				actionMan.executeAction 0 "50026"  -- Tools: Maximize Viewport Toggle
				redrawViews()
				actionMan.executeAction 0 "50026"  -- Tools: Maximize Viewport Toggle
			)
			else(
				actionMan.executeAction 0 "50026"  -- Tools: Maximize Viewport Toggle
				displaySafeFrames = true
				actionMan.executeAction 0 "50026"  -- Tools: Maximize Viewport Toggle
				redrawViews()
				actionMan.executeAction 0 "50026"  -- Tools: Maximize Viewport Toggle
			)--End of viewcount if then
		)

	on RendererDialog close do
		(
rollout openPrev "Open Last File?"
(
button btnOpenLast "Open Last File?" height:17 toolTip: "Opens previous file before Material change"
button btnCloseWindow "Close" height:17 

on btnOpenLast pressed do
(
	yourCombo = (yourPath + yourName)
	yourFile = (yourCombo + ".max")

	loadMaxFile yourFile
	try(destroyDialog openPrev) catch()
)--End of btnOpenLast

on btnCloseWindow pressed do
(
		try(deleteFile "C:\\Renderer\\temp.max") catch()	
		callbacks.removeScripts id:#bio_skin
		lightTintColor = [255,255,255]
		backgroundColor = [0,0,0]
		renderers.production.mapping = true
		try(renderSceneDialog.close()) catch()
		try(MatEditor.Close()) catch()
		try(envEffectsDialog.Close()) catch()
		try(delete #($Key3p, $Fill3p, $Rim3p, $3pointLightBase, $RendererGround)) catch()
		meditMaterials[15] = Standardmaterial ()
		meditMaterials[15].name = "15 - Default"
		meditMaterials[14] = Standardmaterial ()
		meditMaterials[14].name = "14 - Default"
		try(delete $RendererCam) catch()
		try(delete #($LightBase, $front, $frontright, $right, $backright, $backleft, $left, $frontleft, $topright, $topback, $topleft, $key)) catch() 
		displaySafeFrames = false
		try(destroyDialog openPrev) catch()
)--End of btnCloseWindow

on openPrev close do
(
		try(deleteFile "C:\\Renderer\\temp.max") catch()	
		callbacks.removeScripts id:#bio_skin
		lightTintColor = [255,255,255]
		backgroundColor = [0,0,0]
		renderers.production.mapping = true
		try(renderSceneDialog.close()) catch()
		try(MatEditor.Close()) catch()
		try(envEffectsDialog.Close()) catch()
		try(delete #($Key3p, $Fill3p, $Rim3p, $3pointLightBase, $RendererGround)) catch()
		meditMaterials[15] = Standardmaterial ()
		meditMaterials[15].name = "15 - Default"
		meditMaterials[14] = Standardmaterial ()
		meditMaterials[14].name = "14 - Default"
		try(delete $RendererCam) catch()
		try(delete #($LightBase, $front, $frontright, $right, $backright, $backleft, $left, $frontleft, $topright, $topback, $topleft, $key)) catch() 
		displaySafeFrames = false
		try(destroyDialog openPrev) catch()
)--End of Close commands
)--End of Rollout
createDialog openPrev

		)--end of close functions

----------------------------------------------------------------------------------------------------------
-- End of rollout & Create Dialog / Floater
-----------------------------------------------------------------------------------------------------------
	)--end rollout

CreateDialog RendererDialog width:120 height:950 pos:[1856,80] \
style:#(#style_border, #style_titlebar, #style_sysmenu, #style_minimizebox, #style_resizing)
try(cui.RegisterDialogBar RendererDialog minsize:[120,380] maxsize:[120,1500]) catch()

)--End of Script